"""Bumpers - Safety guardrails for AI agents"""

from .types import ValidationPoint, ValidationResult, FailStrategy

__version__ = "0.1.2"

__all__ = ["ValidationPoint", "ValidationResult", "FailStrategy"] 